#!/usr/bin/python

### PharmAnnot PIPELINE ###
## tsv2vcf.py
## Version : 1.1.0
## Description : Conversion a tsv file in vcf file.
## Usage : python tsv2vcf.py -i <input/tsv/file> -p <input/tsv/file> -m<input/tsv/file> -o <output/vcf/file> -e <log/file>
## Output : vcf file
## Requirements : python 2.7+

## Author : Simon.Verdez@chu-dijon.fr
## Creation Date : 20180709
## last revision date : 20180731
## Known bugs : None

import os
import sys
import vcf
import csv
from VCF_tools import *
import subprocess
from operator import *
import getopt
import logging

#Options
try:
    opts, args = getopt.getopt(sys.argv[1:], 'i:p:m:o:e:')
    for opt, arg in opts:
        if opt in ("-i"):
            tsvfile = arg
        if opt in ("-p"):
            pharmgkb = arg
        if opt in ("-m"):
            OMIM = arg
        elif opt in ("-o"):
            out_vcf = arg
        elif opt in ("-e"):
            logfile = arg
except getopt.GetoptError:
    print 'usage : '
    sys.exit(1)

# Logging
logging.basicConfig(filename =  '%s' % (logfile), filemode = 'a', level = logging.INFO, format = '%(asctime)s %(levelname)s - %(message)s')
logging.info('start')

# Manage options
if not vars().has_key('tsvfile'):
    logging.exception('No input file given')
    sys.exit(1)
if not vars().has_key('pharmgkb'):
    logging.exception('No pharmgkb database given')
    sys.exit(1)
if not vars().has_key('OMIM'):
    logging.exception('No OMIM database given')
    sys.exit(1)

# Check files
try:
	f = open(tsvfile, 'r')
	f.close()
except IOError:
    logging.exception('Input file does not exist')
    sys.exit(1)
try:
	f = open(pharmgkb, 'r')
	f.close()
except IOError:
    logging.exception('Clinvar file does not exist')
    sys.exit(1)
try:
	f = open(OMIM, 'r')
	f.close()
except IOError:
    logging.exception('Hgmd file does not exist')
    sys.exit(1)



"""Liste contenant les genes d'interets"""
ListeG = []

"""recuperation des genes dans le fichier"""
with open(pharmgkb) as pharmfile:
    reader = csv.DictReader(pharmfile, dialect='excel-tab')
    for row in reader:
        if row['gene'] != "":
            if row['gene'] not in ListeG:
                ListeG.append(row['gene'])
with open(OMIM) as OMIMfile:
    reader = csv.DictReader(OMIMfile, dialect='excel-tab')
    for row in reader:
        if row['GENE'] != "":
            if row['GENE'] not in ListeG:
                ListeG.append(row['GENE'])
#print ListeG

"""ecriture des lignes CNV dans le vcf"""

ListeVCF=[]

for gene in ListeG:
    with open(tsvfile) as file:
        reader = csv.DictReader(file, dialect='excel-tab')
        for row in reader:
            if gene in row['GeneList'] and gene != "":
                line_vcf = VCF_CNV()
                line_vcf.CHROM = row["#CHR"]
                line_vcf.POS = row["START"]
                p = subprocess.Popen(["samtools", 'faidx',"/work/gad/sv347413/epilepsie/Pipeline/index/hg19_essential.fa", row["#CHR"]+":"+row["START"]+"-"+row["START"]], stdout = subprocess.PIPE)
                line_vcf.REF = p.stdout.readlines()[1].strip("\n")
                line_vcf.ALT = "<"+row["CNV"]+">"
                line_vcf.QUAL = "6"
                line_vcf.SVTYPE = row["CNV"]
                line_vcf.END = row["END"]
                if row["CNV"] == "DEL":
                    line_vcf.SVLEN = "-"+row["CNVLength"]
                else :
                    line_vcf.SVLEN =row["CNVLength"]
                line_vcf.GENE = str(gene)
                ListeVCF.append(line_vcf)

ListeVCF = sorted(ListeVCF,key=attrgetter('POS'))

for line in ListeVCF:
    with open (out_vcf,'a') as vcf_out:
        vcf_out.write(repr(line)+"\n")
